#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using System.Globalization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Prerecorded seasonality indicator that can be used on weekly ES charts.
	/// Based on historical index data between 1970 and 2003.
	/// Copyright www.Emini-Watch.com  All rights reserved. 
    /// </summary>
    [Description("Prerecorded seasonality indicator that can be used on weekly ES charts. Based on historical index data between 1970 and 2003. Copyright www.Emini-Watch.com  All rights reserved. ")]
    public class EminiWatch_WeeklySeasonalityIndicator : Indicator
    {
		private double[] seasonalityValues = {	 0.16,-0.17, 0.25,-0.03, 0.96, 0.87, 0.85, 0.64, 1.11, 1.12, 1.48, 1.32, 1.01,
												 0.69, 1.01, 1.42, 1.22, 1.29, 1.21, 0.95, 1.06, 1.19, 1.41, 1.37, 0.97, 0.83,
												 0.95, 1.17, 1.05, 0.28, 0.44, 0.10, 0.07, 0.32, 0.12,-0.32,-0.96,-1.27,-1.63,
												-1.57,-1.29,-1.36,-2.08,-1.50,-1.11,-1.24,-1.05,-0.83,-1.06,-1.37,-0.78, 0.00};

        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Cyan), PlotStyle.Line, "WeeklySeasonality"));
			Add(new Line(Color.White, 0, "Zero"));
            Overlay	= false;
        }

        protected override void OnBarUpdate()
        {
			if (BarsPeriod.Id != PeriodType.Week)
				return;
			DateTimeFormatInfo	dtInfo   = DateTimeFormatInfo.CurrentInfo;
			Calendar			calendar = dtInfo.Calendar;
			int 				weekNr   = calendar.GetWeekOfYear(Time[0], dtInfo.CalendarWeekRule, dtInfo.FirstDayOfWeek);
			weekNr = Math.Max(1,  weekNr);
			weekNr = Math.Min(52, weekNr);
            Value.Set(seasonalityValues[weekNr - 1]);
        }
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private EminiWatch_WeeklySeasonalityIndicator[] cacheEminiWatch_WeeklySeasonalityIndicator = null;

        private static EminiWatch_WeeklySeasonalityIndicator checkEminiWatch_WeeklySeasonalityIndicator = new EminiWatch_WeeklySeasonalityIndicator();

        /// <summary>
        /// Prerecorded seasonality indicator that can be used on weekly ES charts. Based on historical index data between 1970 and 2003. Copyright www.Emini-Watch.com  All rights reserved. 
        /// </summary>
        /// <returns></returns>
        public EminiWatch_WeeklySeasonalityIndicator EminiWatch_WeeklySeasonalityIndicator()
        {
            return EminiWatch_WeeklySeasonalityIndicator(Input);
        }

        /// <summary>
        /// Prerecorded seasonality indicator that can be used on weekly ES charts. Based on historical index data between 1970 and 2003. Copyright www.Emini-Watch.com  All rights reserved. 
        /// </summary>
        /// <returns></returns>
        public EminiWatch_WeeklySeasonalityIndicator EminiWatch_WeeklySeasonalityIndicator(Data.IDataSeries input)
        {
            if (cacheEminiWatch_WeeklySeasonalityIndicator != null)
                for (int idx = 0; idx < cacheEminiWatch_WeeklySeasonalityIndicator.Length; idx++)
                    if (cacheEminiWatch_WeeklySeasonalityIndicator[idx].EqualsInput(input))
                        return cacheEminiWatch_WeeklySeasonalityIndicator[idx];

            lock (checkEminiWatch_WeeklySeasonalityIndicator)
            {
                if (cacheEminiWatch_WeeklySeasonalityIndicator != null)
                    for (int idx = 0; idx < cacheEminiWatch_WeeklySeasonalityIndicator.Length; idx++)
                        if (cacheEminiWatch_WeeklySeasonalityIndicator[idx].EqualsInput(input))
                            return cacheEminiWatch_WeeklySeasonalityIndicator[idx];

                EminiWatch_WeeklySeasonalityIndicator indicator = new EminiWatch_WeeklySeasonalityIndicator();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                EminiWatch_WeeklySeasonalityIndicator[] tmp = new EminiWatch_WeeklySeasonalityIndicator[cacheEminiWatch_WeeklySeasonalityIndicator == null ? 1 : cacheEminiWatch_WeeklySeasonalityIndicator.Length + 1];
                if (cacheEminiWatch_WeeklySeasonalityIndicator != null)
                    cacheEminiWatch_WeeklySeasonalityIndicator.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheEminiWatch_WeeklySeasonalityIndicator = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Prerecorded seasonality indicator that can be used on weekly ES charts. Based on historical index data between 1970 and 2003. Copyright www.Emini-Watch.com  All rights reserved. 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.EminiWatch_WeeklySeasonalityIndicator EminiWatch_WeeklySeasonalityIndicator()
        {
            return _indicator.EminiWatch_WeeklySeasonalityIndicator(Input);
        }

        /// <summary>
        /// Prerecorded seasonality indicator that can be used on weekly ES charts. Based on historical index data between 1970 and 2003. Copyright www.Emini-Watch.com  All rights reserved. 
        /// </summary>
        /// <returns></returns>
        public Indicator.EminiWatch_WeeklySeasonalityIndicator EminiWatch_WeeklySeasonalityIndicator(Data.IDataSeries input)
        {
            return _indicator.EminiWatch_WeeklySeasonalityIndicator(input);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Prerecorded seasonality indicator that can be used on weekly ES charts. Based on historical index data between 1970 and 2003. Copyright www.Emini-Watch.com  All rights reserved. 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.EminiWatch_WeeklySeasonalityIndicator EminiWatch_WeeklySeasonalityIndicator()
        {
            return _indicator.EminiWatch_WeeklySeasonalityIndicator(Input);
        }

        /// <summary>
        /// Prerecorded seasonality indicator that can be used on weekly ES charts. Based on historical index data between 1970 and 2003. Copyright www.Emini-Watch.com  All rights reserved. 
        /// </summary>
        /// <returns></returns>
        public Indicator.EminiWatch_WeeklySeasonalityIndicator EminiWatch_WeeklySeasonalityIndicator(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.EminiWatch_WeeklySeasonalityIndicator(input);
        }
    }
}
#endregion
